==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/offazurespringboot/kotlin/inputs/SpringbootappsPropertiesMiscsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.offazurespringboot.kotlin.inputs

import com.pulumi.azurenative.offazurespringboot.inputs.SpringbootappsPropertiesMiscsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property key The miscs. key.
 * @property value The miscs. value.
 */
public data class SpringbootappsPropertiesMiscsArgs(
    public val key: Output<String>,
    public val `value`: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.offazurespringboot.inputs.SpringbootappsPropertiesMiscsArgs> {
    override fun toJava():
        com.pulumi.azurenative.offazurespringboot.inputs.SpringbootappsPropertiesMiscsArgs =
        com.pulumi.azurenative.offazurespringboot.inputs.SpringbootappsPropertiesMiscsArgs.builder()
            .key(key.applyValue({ args0 -> args0 }))
            .`value`(`value`?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [SpringbootappsPropertiesMiscsArgs].
 */
@PulumiTagMarker
public class SpringbootappsPropertiesMiscsArgsBuilder internal constructor() {
    private var key: Output<String>? = null

    private var `value`: Output<String>? = null

    /**
     * @param value The miscs. key.
     */
    @JvmName("sbfmyhofahrshrat")
    public suspend fun key(`value`: Output<String>) {
        this.key = value
    }

    /**
     * @param value The miscs. value.
     */
    @JvmName("onsnmljirsogxacm")
    public suspend fun `value`(`value`: Output<String>) {
        this.`value` = value
    }

    /**
     * @param value The miscs. key.
     */
    @JvmName("ahbhlbkysrienuaw")
    public suspend fun key(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.key = mapped
    }

    /**
     * @param value The miscs. value.
     */
    @JvmName("misesowukxiacgam")
    public suspend fun `value`(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.`value` = mapped
    }

    internal fun build(): SpringbootappsPropertiesMiscsArgs = SpringbootappsPropertiesMiscsArgs(
        key = key ?: throw PulumiNullFieldException("key"),
        `value` = `value`,
    )
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/offazurespringboot/kotlin/inputs/SpringbootappsPropertiesMiscsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.offazurespringboot.kotlin.inputs

import com.pulumi.azurenative.offazurespringboot.inputs.SpringbootappsPropertiesMiscsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property key The miscs. key.
 * @property value The miscs. value.
 */
public data class SpringbootappsPropertiesMiscsArgs(
    public val key: Output<String>,
    public val `value`: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.offazurespringboot.inputs.SpringbootappsPropertiesMiscsArgs> {
    override fun toJava(): com.pulumi.azurenative.offazurespringboot.inputs.SpringbootappsPropertiesMiscsArgs =
        com.pulumi.azurenative.offazurespringboot.inputs.SpringbootappsPropertiesMiscsArgs.builder()
            .key(key.applyValue({ args0 -> args0 }))
            .`value`(`value`?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [SpringbootappsPropertiesMiscsArgs].
 */
@PulumiTagMarker
public class SpringbootappsPropertiesMiscsArgsBuilder internal constructor() {
    private var key: Output<String>? = null

    private var `value`: Output<String>? = null

    /**
     * @param value The miscs. key.
     */
    @JvmName("rnbkxdmrwgndtsif")
    public suspend fun key(`value`: Output<String>) {
        this.key = value
    }

    /**
     * @param value The miscs. value.
     */
    @JvmName("cghkfgnbkdoevgfm")
    public suspend fun `value`(`value`: Output<String>) {
        this.`value` = value
    }

    /**
     * @param value The miscs. key.
     */
    @JvmName("sbhheyjcfixjjehd")
    public suspend fun key(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.key = mapped
    }

    /**
     * @param value The miscs. value.
     */
    @JvmName("qqdudtsxbqmqqmtb")
    public suspend fun `value`(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.`value` = mapped
    }

    internal fun build(): SpringbootappsPropertiesMiscsArgs = SpringbootappsPropertiesMiscsArgs(
        key = key ?: throw PulumiNullFieldException("key"),
        `value` = `value`,
    )
}
